[Libreoffice-commits] core.git: sw/source

Miklos Vajna vmiklos at collabora.co.uk
Wed Sep 30 00:10:52 PDT 2015


 sw/source/core/inc/frmtool.hxx    |  132 ++++++++++++++++----------------
 sw/source/core/layout/frmtool.cxx |  156 +++++++++++++++++++-------------------
 2 files changed, 144 insertions(+), 144 deletions(-)

New commits:
commit ba50da44888281c4f0c7fac5effd6d82d154455c
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Wed Sep 30 09:08:57 2015 +0200

    sw: prefix members of SwBorderAttrs
    
    Change-Id: I087c1c63778a7f09179388f73a1a5a87c191a134

diff --git a/sw/source/core/layout/frmtool.cxx b/sw/source/core/layout/frmtool.cxx
index 829faae..ecb637c 100644
--- a/sw/source/core/layout/frmtool.cxx
+++ b/sw/source/core/layout/frmtool.cxx
@@ -1819,52 +1819,52 @@ void MakeFrms( SwDoc *pDoc, const SwNodeIndex &rSttIdx,
 
 SwBorderAttrs::SwBorderAttrs(const SwModify *pMod, const SwFrm *pConstructor)
     : SwCacheObj(pMod)
-    , rAttrSet(pConstructor->IsContentFrm()
+    , m_rAttrSet(pConstructor->IsContentFrm()
                     ? static_cast<const SwContentFrm*>(pConstructor)->GetNode()->GetSwAttrSet()
                     : static_cast<const SwLayoutFrm*>(pConstructor)->GetFormat()->GetAttrSet())
-    , rUL(rAttrSet.GetULSpace())
+    , m_rUL(m_rAttrSet.GetULSpace())
     // #i96772#
     // LRSpaceItem is copied due to the possibility that it is adjusted - see below
-    , rLR(rAttrSet.GetLRSpace())
-    , rBox(rAttrSet.GetBox())
-    , rShadow(rAttrSet.GetShadow())
-    , aFrmSize(rAttrSet.GetFrmSize().GetSize())
-    , bIsLine(false)
-    , bJoinedWithPrev(false)
-    , bJoinedWithNext(false)
-    , nTopLine(0)
-    , nBottomLine(0)
-    , nLeftLine(0)
-    , nRightLine(0)
-    , nTop(0)
-    , nBottom(0)
-    , nGetTopLine(0)
-    , nGetBottomLine(0)
+    , m_rLR(m_rAttrSet.GetLRSpace())
+    , m_rBox(m_rAttrSet.GetBox())
+    , m_rShadow(m_rAttrSet.GetShadow())
+    , m_aFrameSize(m_rAttrSet.GetFrmSize().GetSize())
+    , m_bIsLine(false)
+    , m_bJoinedWithPrev(false)
+    , m_bJoinedWithNext(false)
+    , m_nTopLine(0)
+    , m_nBottomLine(0)
+    , m_nLeftLine(0)
+    , m_nRightLine(0)
+    , m_nTop(0)
+    , m_nBottom(0)
+    , m_nGetTopLine(0)
+    , m_nGetBottomLine(0)
 {
     // #i96772#
     const SwTextFrm* pTextFrm = dynamic_cast<const SwTextFrm*>(pConstructor);
     if ( pTextFrm )
     {
-        pTextFrm->GetTextNode()->ClearLRSpaceItemDueToListLevelIndents( rLR );
+        pTextFrm->GetTextNode()->ClearLRSpaceItemDueToListLevelIndents( m_rLR );
     }
     else if ( pConstructor->IsNoTextFrm() )
     {
-        rLR = SvxLRSpaceItem ( RES_LR_SPACE );
+        m_rLR = SvxLRSpaceItem ( RES_LR_SPACE );
     }
 
     // Caution: The USHORTs for the cached values are not initialized by intention!
 
     // everything needs to be calculated at least once:
-    bTopLine = bBottomLine = bLeftLine = bRightLine =
-    bTop     = bBottom     = bLine   = true;
+    m_bTopLine = m_bBottomLine = m_bLeftLine = m_bRightLine =
+    m_bTop     = m_bBottom     = m_bLine   = true;
 
-    bCacheGetLine = bCachedGetTopLine = bCachedGetBottomLine = false;
-    // OD 21.05.2003 #108789# - init cache status for values <bJoinedWithPrev>
-    // and <bJoinedWithNext>, which aren't initialized by default.
-    bCachedJoinedWithPrev = false;
-    bCachedJoinedWithNext = false;
+    m_bCacheGetLine = m_bCachedGetTopLine = m_bCachedGetBottomLine = false;
+    // OD 21.05.2003 #108789# - init cache status for values <m_bJoinedWithPrev>
+    // and <m_bJoinedWithNext>, which aren't initialized by default.
+    m_bCachedJoinedWithPrev = false;
+    m_bCachedJoinedWithNext = false;
 
-    bBorderDist = 0 != (pConstructor->GetType() & (FRM_CELL));
+    m_bBorderDist = 0 != (pConstructor->GetType() & (FRM_CELL));
 }
 
 SwBorderAttrs::~SwBorderAttrs()
@@ -1879,14 +1879,14 @@ SwBorderAttrs::~SwBorderAttrs()
 
 void SwBorderAttrs::_CalcTop()
 {
-    nTop = CalcTopLine() + rUL.GetUpper();
-    bTop = false;
+    m_nTop = CalcTopLine() + m_rUL.GetUpper();
+    m_bTop = false;
 }
 
 void SwBorderAttrs::_CalcBottom()
 {
-    nBottom = CalcBottomLine() + rUL.GetLower();
-    bBottom = false;
+    m_nBottom = CalcBottomLine() + m_rUL.GetLower();
+    m_bBottom = false;
 }
 
 long SwBorderAttrs::CalcRight( const SwFrm* pCaller ) const
@@ -1904,9 +1904,9 @@ long SwBorderAttrs::CalcRight( const SwFrm* pCaller ) const
     }
     // for paragraphs, "left" is "before text" and "right" is "after text"
     if ( pCaller->IsTextFrm() && pCaller->IsRightToLeft() )
-        nRight += rLR.GetLeft();
+        nRight += m_rLR.GetLeft();
     else
-        nRight += rLR.GetRight();
+        nRight += m_rLR.GetRight();
 
     // correction: retrieve left margin for numbering in R2L-layout
     if ( pCaller->IsTextFrm() && pCaller->IsRightToLeft() )
@@ -1952,7 +1952,7 @@ long SwBorderAttrs::CalcLeft( const SwFrm *pCaller ) const
 
     // for paragraphs, "left" is "before text" and "right" is "after text"
     if ( pCaller->IsTextFrm() && pCaller->IsRightToLeft() )
-        nLeft += rLR.GetRight();
+        nLeft += m_rLR.GetRight();
     else
     {
         bool bIgnoreMargin = false;
@@ -1970,7 +1970,7 @@ long SwBorderAttrs::CalcLeft( const SwFrm *pCaller ) const
             }
         }
         if (!bIgnoreMargin)
-            nLeft += rLR.GetLeft();
+            nLeft += m_rLR.GetLeft();
     }
 
     // correction: do not retrieve left margin for numbering in R2L-layout
@@ -1989,45 +1989,45 @@ long SwBorderAttrs::CalcLeft( const SwFrm *pCaller ) const
 
 void SwBorderAttrs::_CalcTopLine()
 {
-    nTopLine = (bBorderDist && !rBox.GetTop())
-                            ? rBox.GetDistance  (SvxBoxItemLine::TOP)
-                            : rBox.CalcLineSpace(SvxBoxItemLine::TOP);
-    nTopLine = nTopLine + rShadow.CalcShadowSpace(SvxShadowItemSide::TOP);
-    bTopLine = false;
+    m_nTopLine = (m_bBorderDist && !m_rBox.GetTop())
+                            ? m_rBox.GetDistance  (SvxBoxItemLine::TOP)
+                            : m_rBox.CalcLineSpace(SvxBoxItemLine::TOP);
+    m_nTopLine = m_nTopLine + m_rShadow.CalcShadowSpace(SvxShadowItemSide::TOP);
+    m_bTopLine = false;
 }
 
 void SwBorderAttrs::_CalcBottomLine()
 {
-    nBottomLine = (bBorderDist && !rBox.GetBottom())
-                            ? rBox.GetDistance  (SvxBoxItemLine::BOTTOM)
-                            : rBox.CalcLineSpace(SvxBoxItemLine::BOTTOM);
-    nBottomLine = nBottomLine + rShadow.CalcShadowSpace(SvxShadowItemSide::BOTTOM);
-    bBottomLine = false;
+    m_nBottomLine = (m_bBorderDist && !m_rBox.GetBottom())
+                            ? m_rBox.GetDistance  (SvxBoxItemLine::BOTTOM)
+                            : m_rBox.CalcLineSpace(SvxBoxItemLine::BOTTOM);
+    m_nBottomLine = m_nBottomLine + m_rShadow.CalcShadowSpace(SvxShadowItemSide::BOTTOM);
+    m_bBottomLine = false;
 }
 
 void SwBorderAttrs::_CalcLeftLine()
 {
-    nLeftLine = (bBorderDist && !rBox.GetLeft())
-                            ? rBox.GetDistance  (SvxBoxItemLine::LEFT)
-                            : rBox.CalcLineSpace(SvxBoxItemLine::LEFT);
-    nLeftLine = nLeftLine + rShadow.CalcShadowSpace(SvxShadowItemSide::LEFT);
-    bLeftLine = false;
+    m_nLeftLine = (m_bBorderDist && !m_rBox.GetLeft())
+                            ? m_rBox.GetDistance  (SvxBoxItemLine::LEFT)
+                            : m_rBox.CalcLineSpace(SvxBoxItemLine::LEFT);
+    m_nLeftLine = m_nLeftLine + m_rShadow.CalcShadowSpace(SvxShadowItemSide::LEFT);
+    m_bLeftLine = false;
 }
 
 void SwBorderAttrs::_CalcRightLine()
 {
-    nRightLine = (bBorderDist && !rBox.GetRight())
-                            ? rBox.GetDistance  (SvxBoxItemLine::RIGHT)
-                            : rBox.CalcLineSpace(SvxBoxItemLine::RIGHT);
-    nRightLine = nRightLine + rShadow.CalcShadowSpace(SvxShadowItemSide::RIGHT);
-    bRightLine = false;
+    m_nRightLine = (m_bBorderDist && !m_rBox.GetRight())
+                            ? m_rBox.GetDistance  (SvxBoxItemLine::RIGHT)
+                            : m_rBox.CalcLineSpace(SvxBoxItemLine::RIGHT);
+    m_nRightLine = m_nRightLine + m_rShadow.CalcShadowSpace(SvxShadowItemSide::RIGHT);
+    m_bRightLine = false;
 }
 
 void SwBorderAttrs::_IsLine()
 {
-    bIsLine = rBox.GetTop() || rBox.GetBottom() ||
-              rBox.GetLeft()|| rBox.GetRight();
-    bLine = false;
+    m_bIsLine = m_rBox.GetTop() || m_rBox.GetBottom() ||
+              m_rBox.GetLeft()|| m_rBox.GetRight();
+    m_bLine = false;
 }
 
 /* The borders of neighboring paragraphs are condensed by following algorithm:
@@ -2067,9 +2067,9 @@ bool SwBorderAttrs::_JoinWithCmp( const SwFrm& _rCallerFrm,
 
     SwBorderAttrAccess aCmpAccess( SwFrm::GetCache(), &_rCmpFrm );
     const SwBorderAttrs &rCmpAttrs = *aCmpAccess.Get();
-    if ( rShadow == rCmpAttrs.GetShadow() &&
-         CmpLines( rBox.GetTop(), rCmpAttrs.GetBox().GetTop() ) &&
-         CmpLines( rBox.GetBottom(), rCmpAttrs.GetBox().GetBottom() ) &&
+    if ( m_rShadow == rCmpAttrs.GetShadow() &&
+         CmpLines( m_rBox.GetTop(), rCmpAttrs.GetBox().GetTop() ) &&
+         CmpLines( m_rBox.GetBottom(), rCmpAttrs.GetBox().GetBottom() ) &&
          CmpLeftRight( rCmpAttrs, &_rCallerFrm, &_rCmpFrm )
        )
     {
@@ -2080,13 +2080,13 @@ bool SwBorderAttrs::_JoinWithCmp( const SwFrm& _rCallerFrm,
 }
 
 // OD 21.05.2003 #108789# - method to determine, if borders are joined with
-// previous frame. Calculated value saved in cached value <bJoinedWithPrev>
+// previous frame. Calculated value saved in cached value <m_bJoinedWithPrev>
 // OD 2004-02-26 #i25029# - add 2nd parameter <_pPrevFrm>
 void SwBorderAttrs::_CalcJoinedWithPrev( const SwFrm& _rFrm,
                                          const SwFrm* _pPrevFrm )
 {
     // set default
-    bJoinedWithPrev = false;
+    m_bJoinedWithPrev = false;
 
     if ( _rFrm.IsTextFrm() )
     {
@@ -2105,22 +2105,22 @@ void SwBorderAttrs::_CalcJoinedWithPrev( const SwFrm& _rFrm,
              pPrevFrm->GetAttrSet()->GetParaConnectBorder().GetValue()
            )
         {
-            bJoinedWithPrev = _JoinWithCmp( _rFrm, *(pPrevFrm) );
+            m_bJoinedWithPrev = _JoinWithCmp( _rFrm, *(pPrevFrm) );
         }
     }
 
     // valid cache status, if demanded
     // OD 2004-02-26 #i25029# - Do not validate cache, if parameter <_pPrevFrm>
     // is set.
-    bCachedJoinedWithPrev = bCacheGetLine && !_pPrevFrm;
+    m_bCachedJoinedWithPrev = m_bCacheGetLine && !_pPrevFrm;
 }
 
 // OD 21.05.2003 #108789# - method to determine, if borders are joined with
-// next frame. Calculated value saved in cached value <bJoinedWithNext>
+// next frame. Calculated value saved in cached value <m_bJoinedWithNext>
 void SwBorderAttrs::_CalcJoinedWithNext( const SwFrm& _rFrm )
 {
     // set default
-    bJoinedWithNext = false;
+    m_bJoinedWithNext = false;
 
     if ( _rFrm.IsTextFrm() )
     {
@@ -2137,37 +2137,37 @@ void SwBorderAttrs::_CalcJoinedWithNext( const SwFrm& _rFrm )
              _rFrm.GetAttrSet()->GetParaConnectBorder().GetValue()
            )
         {
-            bJoinedWithNext = _JoinWithCmp( _rFrm, *(pNextFrm) );
+            m_bJoinedWithNext = _JoinWithCmp( _rFrm, *(pNextFrm) );
         }
     }
 
     // valid cache status, if demanded
-    bCachedJoinedWithNext = bCacheGetLine;
+    m_bCachedJoinedWithNext = m_bCacheGetLine;
 }
 
-// OD 21.05.2003 #108789# - accessor for cached values <bJoinedWithPrev>
+// OD 21.05.2003 #108789# - accessor for cached values <m_bJoinedWithPrev>
 // OD 2004-02-26 #i25029# - add 2nd parameter <_pPrevFrm>, which is passed to
 // method <_CalcJoindWithPrev(..)>.
 bool SwBorderAttrs::JoinedWithPrev( const SwFrm& _rFrm,
                                     const SwFrm* _pPrevFrm ) const
 {
-    if ( !bCachedJoinedWithPrev || _pPrevFrm )
+    if ( !m_bCachedJoinedWithPrev || _pPrevFrm )
     {
         // OD 2004-02-26 #i25029# - pass <_pPrevFrm> as 2nd parameter
         const_cast<SwBorderAttrs*>(this)->_CalcJoinedWithPrev( _rFrm, _pPrevFrm );
     }
 
-    return bJoinedWithPrev;
+    return m_bJoinedWithPrev;
 }
 
 bool SwBorderAttrs::JoinedWithNext( const SwFrm& _rFrm ) const
 {
-    if ( !bCachedJoinedWithNext )
+    if ( !m_bCachedJoinedWithNext )
     {
         const_cast<SwBorderAttrs*>(this)->_CalcJoinedWithNext( _rFrm );
     }
 
-    return bJoinedWithNext;
+    return m_bJoinedWithNext;
 }
 
 // OD 2004-02-26 #i25029# - added 2nd parameter <_pPrevFrm>, which is passed to
@@ -2184,9 +2184,9 @@ void SwBorderAttrs::_GetTopLine( const SwFrm& _rFrm,
         nRet = 0;
     }
 
-    bCachedGetTopLine = bCacheGetLine;
+    m_bCachedGetTopLine = m_bCacheGetLine;
 
-    nGetTopLine = nRet;
+    m_nGetTopLine = nRet;
 }
 
 void SwBorderAttrs::_GetBottomLine( const SwFrm& _rFrm )
@@ -2199,9 +2199,9 @@ void SwBorderAttrs::_GetBottomLine( const SwFrm& _rFrm )
         nRet = 0;
     }
 
-    bCachedGetBottomLine = bCacheGetLine;
+    m_bCachedGetBottomLine = m_bCacheGetLine;
 
-    nGetBottomLine = nRet;
+    m_nGetBottomLine = nRet;
 }
 
 SwBorderAttrAccess::SwBorderAttrAccess( SwCache &rCach, const SwFrm *pFrm ) :


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/core/inc/frmtool.hxx b/sw/source/core/inc/frmtool.hxx
index cc58afc..68e9cc0 100644
--- a/sw/source/core/inc/frmtool.hxx
+++ b/sw/source/core/inc/frmtool.hxx
@@ -253,50 +253,50 @@ public:
 //          Modify::Modify!
 class SwBorderAttrs : public SwCacheObj
 {
-    const SwAttrSet      &rAttrSet;
-    const SvxULSpaceItem &rUL;
+    const SwAttrSet      &m_rAttrSet;
+    const SvxULSpaceItem &m_rUL;
     // #i96772#
-    SvxLRSpaceItem rLR;
-    const SvxBoxItem     &rBox;
-    const SvxShadowItem  &rShadow;
-    const Size            aFrmSize;
+    SvxLRSpaceItem m_rLR;
+    const SvxBoxItem     &m_rBox;
+    const SvxShadowItem  &m_rShadow;
+    const Size            m_aFrameSize;
 
     // Is it a frame that can have a margin without a border?
-    bool bBorderDist  : 1;
+    bool m_bBorderDist  : 1;
 
     // the following bool values set the cached values to INVALID - until they
     // are calculated for the first time
-    bool bTopLine     : 1;
-    bool bBottomLine  : 1;
-    bool bLeftLine    : 1;
-    bool bRightLine   : 1;
-    bool bTop         : 1;
-    bool bBottom      : 1;
-    bool bLine        : 1;
-
-    bool bIsLine      : 1; // border on at least one side?
-
-    bool bCacheGetLine        : 1; // cache GetTopLine(), GetBottomLine()?
-    bool bCachedGetTopLine    : 1; // is GetTopLine() cached?
-    bool bCachedGetBottomLine : 1; // is GetBottomLine() cached?
-    // Booleans indicate that <bJoinedWithPrev> and <bJoinedWithNext> are
+    bool m_bTopLine     : 1;
+    bool m_bBottomLine  : 1;
+    bool m_bLeftLine    : 1;
+    bool m_bRightLine   : 1;
+    bool m_bTop         : 1;
+    bool m_bBottom      : 1;
+    bool m_bLine        : 1;
+
+    bool m_bIsLine      : 1; // border on at least one side?
+
+    bool m_bCacheGetLine        : 1; // cache GetTopLine(), GetBottomLine()?
+    bool m_bCachedGetTopLine    : 1; // is GetTopLine() cached?
+    bool m_bCachedGetBottomLine : 1; // is GetBottomLine() cached?
+    // Booleans indicate that <m_bJoinedWithPrev> and <m_bJoinedWithNext> are
     // cached and valid.
-    // Caching depends on value of <bCacheGetLine>.
-    mutable bool bCachedJoinedWithPrev : 1;
-    mutable bool bCachedJoinedWithNext : 1;
+    // Caching depends on value of <m_bCacheGetLine>.
+    mutable bool m_bCachedJoinedWithPrev : 1;
+    mutable bool m_bCachedJoinedWithNext : 1;
     // Booleans indicate that borders are joined with previous/next frame.
-    bool bJoinedWithPrev :1;
-    bool bJoinedWithNext :1;
+    bool m_bJoinedWithPrev :1;
+    bool m_bJoinedWithNext :1;
 
     // The cached values (un-defined until calculated for the first time)
-    sal_uInt16 nTopLine,
-           nBottomLine,
-           nLeftLine,
-           nRightLine,
-           nTop,
-           nBottom,
-           nGetTopLine,
-           nGetBottomLine;
+    sal_uInt16 m_nTopLine,
+           m_nBottomLine,
+           m_nLeftLine,
+           m_nRightLine,
+           m_nTop,
+           m_nBottom,
+           m_nGetTopLine,
+           m_nGetBottomLine;
 
     // only calculate lines and shadow
     void _CalcTopLine();
@@ -316,7 +316,7 @@ class SwBorderAttrs : public SwCacheObj
                          const SwFrm* _pPrevFrm = 0L );
     void _GetBottomLine( const SwFrm& _rFrm );
 
     // calculate cached values <bJoinedWithPrev> and <bJoinedWithNext>
     // #i25029# - If <_pPrevFrm> is set, its value is taken for testing, if
     // borders/shadow have to be joined with previous frame.
     void _CalcJoinedWithPrev( const SwFrm& _rFrm,
@@ -338,10 +338,10 @@ public:
     SwBorderAttrs( const SwModify *pOwner, const SwFrm *pConstructor );
     virtual ~SwBorderAttrs();
 
-    inline const SwAttrSet      &GetAttrSet() const { return rAttrSet;  }
-    inline const SvxULSpaceItem &GetULSpace() const { return rUL;       }
-    inline const SvxBoxItem     &GetBox()     const { return rBox;      }
-    inline const SvxShadowItem  &GetShadow()  const { return rShadow;   }
+    inline const SwAttrSet      &GetAttrSet() const { return m_rAttrSet;  }
+    inline const SvxULSpaceItem &GetULSpace() const { return m_rUL;       }
+    inline const SvxBoxItem     &GetBox()     const { return m_rBox;      }
+    inline const SvxShadowItem  &GetShadow()  const { return m_rShadow;   }
 
     inline sal_uInt16 CalcTopLine() const;
     inline sal_uInt16 CalcBottomLine() const;
@@ -354,9 +354,9 @@ public:
 
     inline bool IsLine() const;
 
-    inline const Size &GetSize()     const { return aFrmSize; }
+    inline const Size &GetSize()     const { return m_aFrameSize; }
 
-    inline bool IsBorderDist() const { return bBorderDist; }
+    inline bool IsBorderDist() const { return m_bBorderDist; }
 
     // Should upper (or lower) border be evaluated for this frame?
     // #i25029# - If <_pPrevFrm> is set, its value is taken for testing, if
@@ -366,7 +366,7 @@ public:
     inline sal_uInt16 GetBottomLine( const SwFrm& _rFrm ) const;
     inline void   SetGetCacheLine( bool bNew ) const;
 
     // Accessors for cached values <bJoinedWithPrev> and <bJoinedWithPrev>
     // #i25029# - If <_pPrevFrm> is set, its value is taken for testing, if
     // borders/shadow have to be joined with previous frame.
     bool JoinedWithPrev( const SwFrm& _rFrm,
@@ -434,69 +434,69 @@ public:
 inline sal_uInt16 SwBorderAttrs::GetTopLine ( const SwFrm& _rFrm,
                                           const SwFrm* _pPrevFrm ) const
 {
-    if ( !bCachedGetTopLine || _pPrevFrm )
+    if ( !m_bCachedGetTopLine || _pPrevFrm )
     {
         const_cast<SwBorderAttrs*>(this)->_GetTopLine( _rFrm, _pPrevFrm );
     }
-    return nGetTopLine;
+    return m_nGetTopLine;
 }
 inline sal_uInt16 SwBorderAttrs::GetBottomLine( const SwFrm& _rFrm ) const
 {
-    if ( !bCachedGetBottomLine )
+    if ( !m_bCachedGetBottomLine )
         const_cast<SwBorderAttrs*>(this)->_GetBottomLine( _rFrm );
-    return nGetBottomLine;
+    return m_nGetBottomLine;
 }
 inline void SwBorderAttrs::SetGetCacheLine( bool bNew ) const
 {
-    const_cast<SwBorderAttrs*>(this)->bCacheGetLine = bNew;
-    const_cast<SwBorderAttrs*>(this)->bCachedGetBottomLine =
-    const_cast<SwBorderAttrs*>(this)->bCachedGetTopLine = false;
-    // invalidate cache for values <bJoinedWithPrev> and <bJoinedWithNext>
-    bCachedJoinedWithPrev = false;
-    bCachedJoinedWithNext = false;
+    const_cast<SwBorderAttrs*>(this)->m_bCacheGetLine = bNew;
+    const_cast<SwBorderAttrs*>(this)->m_bCachedGetBottomLine =
+    const_cast<SwBorderAttrs*>(this)->m_bCachedGetTopLine = false;
+    // invalidate cache for values <m_bJoinedWithPrev> and <m_bJoinedWithNext>
+    m_bCachedJoinedWithPrev = false;
+    m_bCachedJoinedWithNext = false;
 }
 
 inline sal_uInt16 SwBorderAttrs::CalcTopLine() const
 {
-    if ( bTopLine )
+    if ( m_bTopLine )
         const_cast<SwBorderAttrs*>(this)->_CalcTopLine();
-    return nTopLine;
+    return m_nTopLine;
 }
 inline sal_uInt16 SwBorderAttrs::CalcBottomLine() const
 {
-    if ( bBottomLine )
+    if ( m_bBottomLine )
         const_cast<SwBorderAttrs*>(this)->_CalcBottomLine();
-    return nBottomLine;
+    return m_nBottomLine;
 }
 inline sal_uInt16 SwBorderAttrs::CalcLeftLine() const
 {
-    if ( bLeftLine )
+    if ( m_bLeftLine )
         const_cast<SwBorderAttrs*>(this)->_CalcLeftLine();
-    return nLeftLine;
+    return m_nLeftLine;
 }
 inline sal_uInt16 SwBorderAttrs::CalcRightLine() const
 {
-    if ( bRightLine )
+    if ( m_bRightLine )
         const_cast<SwBorderAttrs*>(this)->_CalcRightLine();
-    return nRightLine;
+    return m_nRightLine;
 }
 inline sal_uInt16 SwBorderAttrs::CalcTop() const
 {
-    if ( bTop )
+    if ( m_bTop )
         const_cast<SwBorderAttrs*>(this)->_CalcTop();
-    return nTop;
+    return m_nTop;
 }
 inline sal_uInt16 SwBorderAttrs::CalcBottom() const
 {
-    if ( bBottom )
+    if ( m_bBottom )
         const_cast<SwBorderAttrs*>(this)->_CalcBottom();
-    return nBottom;
+    return m_nBottom;
 }
 inline bool SwBorderAttrs::IsLine() const
 {
-    if ( bLine )
+    if ( m_bLine )
         const_cast<SwBorderAttrs*>(this)->_IsLine();
-    return bIsLine;
+    return m_bIsLine;
 }
 
 /** method to determine the spacing values of a frame
@@ -316,7 +316,7 @@ class SwBorderAttrs : public SwCacheObj
     void _GetBottomLine( const SwFrm& _rFrm );
 
-    // calculate cached values <bJoinedWithPrev> and <bJoinedWithNext>
+    // calculate cached values <m_bJoinedWithPrev> and <m_bJoinedWithNext>
     // #i25029# - If <_pPrevFrm> is set, its value is taken for testing, if
     // borders/shadow have to be joined with previous frame.
@@ -366,7 +366,7 @@ public:
     inline void   SetGetCacheLine( bool bNew ) const;
 
-    // Accessors for cached values <bJoinedWithPrev> and <bJoinedWithPrev>
+    // Accessors for cached values <m_bJoinedWithPrev> and <m_bJoinedWithNext>
     // #i25029# - If <_pPrevFrm> is set, its value is taken for testing, if
     // borders/shadow have to be joined with previous frame.